@@ -314,8 +314,14 @@
         navCon.modalPresentationStyle = UIModalPresentationFormSheet;
         [self presentViewController:navCon animated:YES completion:nil];
 
-        if (loginViewController.navigationItem.leftBarButtonItem == nil)
-            loginViewController.navigationItem.leftBarButtonItem = [UIBarButtonItem themedDarkToolbarButtonWithTitle:NSLocalizedString(@"BUTTON_CANCEL", nil) target:self andSelector:@selector(_dismissLogin)];
+        if (loginViewController.navigationItem.leftBarButtonItem == nil) {
+            loginViewController.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc]
+                                                                    initWithTitle:NSLocalizedString(@"BUTTON_CANCEL", nil)
+                                                                    style:UIBarButtonItemStylePlain
+                                                                    target:self
+                                                                    action:@selector(_dismissLogin)];
+        }
+
     } else {
         [self.navigationController pushViewController:loginViewController animated:YES];
     }
@@ -393,8 +399,6 @@
         APLog(@"Unsupported URL Scheme requested %@", identifier);
     }
 
-    [self _dismissLogin];
-
     if (serverBrowser) {
         VLCNetworkServerBrowserViewController *targetViewController = [[VLCNetworkServerBrowserViewController alloc] initWithServerBrowser:serverBrowser];
         [self.navigationController pushViewController:targetViewController animated:YES];
